import { useMemo } from 'react';
import ReactDOM from 'react-dom';
import { VizContainer } from './VizContainer';
import { useData } from './useData';
import { ForceNetwork } from './ForceNetwork';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = { top: 30, right: 30, bottom: 30, left: 30 };

const App = () => {
  const [innerWidth, innerHeight] = useMemo(()=>{
    const a = width - margin.right - margin.left;
    const b = height - margin.top - margin.bottom;
    return [a, b]
  }, [width, height, margin]);

  // Load Data
  const [nodes, links] = useData();
  
  return (nodes && links) ? (
    <>
      <VizContainer
        id="viz-container"
        width={width}
        height={height}
        margin={margin}
        innerWidth={innerWidth}
        innerHeight={innerHeight}
      >
        <ForceNetwork 
          nodes={nodes} 
          links={links} 
          innerWidth={innerWidth} 
          innerHeight={innerHeight} 
        />
      </VizContainer>
    </>
  ) : <div>Loading...</div>;
};

ReactDOM.render(<App />, document.getElementById('root'));


