import { useEffect, useState } from 'react';
import { csv } from 'd3';

const MAIN_NODE_SIZE = 40;
const CHILD_NODE_SIZE = 15;
const LEAF_NODE_SIZE = 5;
const MAIN_NODE_DISTANCE = 100;
const DEFAULT_DISTANCE = 20;
const LEAF_NODE_DISTANCE = 30;
export const MANY_BODY_STRENGTH = -20;
export const MIN_NODE_DISTANCE = 5;

const nodeSizeMap = new Map();
nodeSizeMap.set('Main', MAIN_NODE_SIZE);
nodeSizeMap.set('Sub', CHILD_NODE_SIZE);
nodeSizeMap.set('Anonymous', LEAF_NODE_SIZE);

const linkDistanceMap = new Map();
linkDistanceMap.set('main_main', MAIN_NODE_DISTANCE);
linkDistanceMap.set('main_sub', DEFAULT_DISTANCE);
linkDistanceMap.set('sub_anonymous', LEAF_NODE_DISTANCE);

export const nodeColorMap = new Map();

const edgeListPath = 'data/edgeList.csv';
const nodeDataPath = 'data/nodeAttr.csv';

export const useData = () => {
  const [nodes, setNodes] = useState(null);
  const [links, setLinks] = useState(null);
	
  let i = 0;
  const nodeListRow = (nodeRow) => {
    if (nodeRow.Type === 'Main'){
      nodeColorMap.set(nodeRow.Node, i++);
    };
    const nodeEntry = {
      id: nodeRow.Node,
      size: nodeSizeMap.get(nodeRow.Type),
    };
    return nodeEntry;
  };
  const edgeListRow = (edgeRow) => {
    if((edgeRow.Type === 'main_sub') || (edgeRow.Type === 'sub_anonymous')){
      const colorIndex = nodeColorMap.get(edgeRow.Source);
      nodeColorMap.set(edgeRow.Target, colorIndex);
    };
    const edgeEntry = {
      source: edgeRow.Source,
      target: edgeRow.Target,
      distance: linkDistanceMap.get(edgeRow.Type),
    };
    return edgeEntry;
  };

  useEffect(() => {
    Promise.all([
      csv(nodeDataPath, nodeListRow),
      csv(edgeListPath, edgeListRow)
    ]).then(([nodeList, edgeList]) => {
      nodeList.columns = ["id", "size", "color"]
      edgeList.columns = ["source", "target", "distance", "color"]
      setLinks(edgeList);
      setNodes(nodeList);
    });
  }, []);

  return [nodes, links];
};
